@@ -3,6 +3,7 @@ import os
 
 import psutil
 import texttable as tt  # from somewhere?
+from itertools import groupby
 
 from plotman import archive, job, manager, plot_util
 
@@ -12,7 +13,7 @@ def abbr_path(path, putative_prefix):
         return os.path.relpath(path, putative_prefix)
     else:
         return path
-    
+
 def phase_str(phase):
     if not phase.known:
         return '?:?'
@@ -37,12 +38,12 @@ def n_at_ph(jobs, ph):
 
 def n_to_char(n):
     n_to_char_map = dict(enumerate(" .:;!"))
-    
+
     if n < 0:
         return 'X'  # Should never be negative
     elif n >= len(n_to_char_map):
         n = len(n_to_char_map) - 1
-    
+
     return n_to_char_map[n]
 
 def job_viz(jobs):
@@ -62,6 +63,8 @@ def job_viz(jobs):
     result += n_to_char(n_at_ph(jobs, job.Phase(4, 0)))
     return result
 
+# Command: plotman status
+# Shows a general overview of all running jobs
 def status_report(jobs, width, height=None, tmp_prefix='', dst_prefix=''):
     '''height, if provided, will limit the number of rows in the table,
        showing first and last rows, row numbers and an elipsis in the middle.'''
@@ -85,10 +88,11 @@ def status_report(jobs, width, height=None, tmp_prefix='', dst_prefix=''):
     tab.set_cols_dtype('t' * len(headings))
     tab.set_cols_align('r' * len(headings))
     tab.set_header_align('r' * len(headings))
+
     for i, j in enumerate(sorted(jobs, key=job.Job.get_time_wall)):
         # Elipsis row
         if abbreviate_jobs_list and i == n_begin_rows:
-            row = ['...'] + ([''] * 13)
+            row = ['...'] + ([''] * (len(headings) - 1))
         # Omitted row
         elif abbreviate_jobs_list and i > n_begin_rows and i < (len(jobs) - n_end_rows):
             continue
@@ -97,19 +101,19 @@ def status_report(jobs, width, height=None, tmp_prefix='', dst_prefix=''):
         else:
             try:
                 with j.proc.oneshot():
-                    row = [j.plot_id[:8],
-                        j.k,
-                        abbr_path(j.tmpdir, tmp_prefix),
-                        abbr_path(j.dstdir, dst_prefix),
-                        plot_util.time_format(j.get_time_wall()),
-                        phase_str(j.progress()),
-                        plot_util.human_format(j.get_tmp_usage(), 0),
-                        j.proc.pid,
-                        j.get_run_status(),
-                        plot_util.human_format(j.get_mem_usage(), 1),
-                        plot_util.time_format(j.get_time_user()),
-                        plot_util.time_format(j.get_time_sys()),
-                        plot_util.time_format(j.get_time_iowait())
+                    row = [j.plot_id[:8], # Plot ID
+                        j.k, # k size
+                        abbr_path(j.tmpdir, tmp_prefix), # Temp directory
+                        abbr_path(j.dstdir, dst_prefix), # Destination directory
+                        plot_util.time_format(j.get_time_wall()), # Time wall
+                        phase_str(j.progress()), # Overall progress (major:minor)
+                        plot_util.human_format(j.get_tmp_usage(), 0), # Current temp file size
+                        j.proc.pid, # System pid
+                        j.get_run_status(), # OS status for the job process
+                        plot_util.human_format(j.get_mem_usage(), 1, True), # Memory usage
+                        plot_util.time_format(j.get_time_user()), # user system time
+                        plot_util.time_format(j.get_time_sys()), # system time
+                        plot_util.time_format(j.get_time_iowait()) # io wait
                         ]
             except (psutil.NoSuchProcess, psutil.AccessDenied):
                 # In case the job has disappeared
@@ -122,9 +126,25 @@ def status_report(jobs, width, height=None, tmp_prefix='', dst_prefix=''):
 
     tab.set_max_width(width)
     tab.set_deco(0)  # No borders
-    # return ('tmp dir prefix: %s ; dst dir prefix: %s\n' % (tmp_prefix, dst_prefix)
+
     return tab.draw()
 
+def summary(jobs, tmp_prefix=''):
+    """Creates a small summary of running jobs"""
+
+    summary = [
+        'Total jobs: {0}'.format(len(jobs))
+    ]
+
+    # Number of jobs in each tmp disk
+    tmp_dir_paths = sorted([abbr_path(job.tmpdir, tmp_prefix) for job in jobs])
+    for key, group in groupby(tmp_dir_paths, lambda dir: dir):
+        summary.append(
+            'Jobs in {0}: {1}'.format(key, len(list(group)))
+        )
+
+    return '\n'.join(summary)
+
 def tmp_dir_report(jobs, dir_cfg, sched_cfg, width, start_row=None, end_row=None, prefix=''):
     '''start_row, end_row let you split the table up if you want'''
     tab = tt.Texttable()
@@ -144,7 +164,7 @@ def tmp_dir_report(jobs, dir_cfg, sched_cfg, width, start_row=None, end_row=None
     tab.set_deco(tt.Texttable.BORDER | tt.Texttable.HEADER )
     tab.set_deco(0)  # No borders
     return tab.draw()
- 
+
 def dst_dir_report(jobs, dstdirs, width, prefix=''):
     tab = tt.Texttable()
     dir2oldphase = manager.dstdirs_to_furthest_phase(jobs)
@@ -156,13 +176,13 @@ def dst_dir_report(jobs, dstdirs, width, prefix=''):
     for d in sorted(dstdirs):
         # TODO: This logic is replicated in archive.py's priority computation,
         # maybe by moving more of the logic in to directory.py
-        eldest_ph = dir2oldphase.get(d, (0, 0))
+        eldest_ph = dir2oldphase.get(d, job.Phase(0, 0))
         phases = job.job_phases_for_dstdir(d, jobs)
 
         dir_plots = plot_util.list_k32_plots(d)
         gb_free = int(plot_util.df_b(d) / plot_util.GB)
         n_plots = len(dir_plots)
-        priority = archive.compute_priority(eldest_ph, gb_free, n_plots) 
+        priority = archive.compute_priority(eldest_ph, gb_free, n_plots)
         row = [abbr_path(d, prefix), n_plots, gb_free,
                 phases_str(phases, 5), priority]
         tab.add_row(row)
@@ -172,7 +192,7 @@ def dst_dir_report(jobs, dstdirs, width, prefix=''):
     return tab.draw()
 
 def arch_dir_report(archdir_freebytes, width, prefix=''):
-    cells = ['%s:%5dGB' % (abbr_path(d, prefix), int(int(space) / plot_util.GB))
+    cells = ['%s:%5dG' % (abbr_path(d, prefix), int(int(space) / plot_util.GB))
             for (d, space) in sorted(archdir_freebytes.items())]
     if not cells:
         return ''
@@ -187,15 +207,18 @@ def arch_dir_report(archdir_freebytes, width, prefix=''):
     return tab.draw()
 
 # TODO: remove this
-def dirs_report(jobs, dir_cfg, sched_cfg, width):
+def dirs_report(jobs, dir_cfg, arch_cfg, sched_cfg, width):
+    dst_dir = dir_cfg.get_dst_directories()
     reports = [
         tmp_dir_report(jobs, dir_cfg, sched_cfg, width),
-        dst_dir_report(jobs, dir_cfg.dst, width),
+        dst_dir_report(jobs, dst_dir, width),
     ]
-    if dir_cfg.archive is not None:
+    if arch_cfg is not None:
+        freebytes, archive_log_messages = archive.get_archdir_freebytes(arch_cfg)
         reports.extend([
             'archive dirs free space:',
-            arch_dir_report(archive.get_archdir_freebytes(dir_cfg.archive), width),
+            arch_dir_report(freebytes, width),
+            *archive_log_messages,
         ])
 
     return '\n'.join(reports) + '\n'
